/**
 * @type {import('unified').Plugin<[Options], Root, ReactElement>}
 */
export default function rehypeReact(options: Options): void
export type Root = import('hast').Root
export type Element = import('hast').Element
export type ReactNode = import('react').ReactNode
export type ReactElement = import('react').ReactElement<unknown>
export type CreateElementLike = (
  name: any,
  props: any,
  ...children: ReactNode[]
) => ReactNode
export type SharedOptions = {
  /**
   * How to create elements or components.
   * You should typically pass `React.createElement`.
   */
  createElement: CreateElementLike
  /**
   * Create fragments instead of an outer `<div>` if available.
   * You should typically pass `React.Fragment`.
   */
  Fragment?: ((props: any) => ReactNode) | undefined
  /**
   * React key prefix
   */
  prefix?: string | undefined
}
export type WithNode = {
  /**
   * Current hast element.
   */
  node: Element
}
export type ComponentsWithNodeOptions = {
  /**
   * Expose hast elements as a `node` field in components.
   */
  passNode: true
  /**
   * Override default elements (such as `<a>`, `<p>`, etcetera) by passing an
   * object mapping tag names to components.
   */
  components?:
    | Partial<{
        a:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLAnchorElement> &
                import('react').AnchorHTMLAttributes<HTMLAnchorElement>
            ) => ReactNode)
        abbr:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        address:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        area:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLAreaElement> &
                import('react').AreaHTMLAttributes<HTMLAreaElement>
            ) => ReactNode)
        article:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        aside:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        audio:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLAudioElement> &
                import('react').AudioHTMLAttributes<HTMLAudioElement>
            ) => ReactNode)
        b:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        base:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLBaseElement> &
                import('react').BaseHTMLAttributes<HTMLBaseElement>
            ) => ReactNode)
        bdi:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        bdo:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        big:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        blockquote:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').BlockquoteHTMLAttributes<HTMLElement>
            ) => ReactNode)
        body:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLBodyElement> &
                import('react').HTMLAttributes<HTMLBodyElement>
            ) => ReactNode)
        br:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLBRElement> &
                import('react').HTMLAttributes<HTMLBRElement>
            ) => ReactNode)
        button:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLButtonElement> &
                import('react').ButtonHTMLAttributes<HTMLButtonElement>
            ) => ReactNode)
        canvas:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLCanvasElement> &
                import('react').CanvasHTMLAttributes<HTMLCanvasElement>
            ) => ReactNode)
        caption:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        cite:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        code:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        col:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableColElement> &
                import('react').ColHTMLAttributes<HTMLTableColElement>
            ) => ReactNode)
        colgroup:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableColElement> &
                import('react').ColgroupHTMLAttributes<HTMLTableColElement>
            ) => ReactNode)
        data:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLDataElement> &
                import('react').DataHTMLAttributes<HTMLDataElement>
            ) => ReactNode)
        datalist:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLDataListElement> &
                import('react').HTMLAttributes<HTMLDataListElement>
            ) => ReactNode)
        dd:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        del:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').DelHTMLAttributes<HTMLElement>
            ) => ReactNode)
        details:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').DetailsHTMLAttributes<HTMLElement>
            ) => ReactNode)
        dfn:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        dialog:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLDialogElement> &
                import('react').DialogHTMLAttributes<HTMLDialogElement>
            ) => ReactNode)
        div:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLDivElement> &
                import('react').HTMLAttributes<HTMLDivElement>
            ) => ReactNode)
        dl:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLDListElement> &
                import('react').HTMLAttributes<HTMLDListElement>
            ) => ReactNode)
        dt:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        em:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        embed:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLEmbedElement> &
                import('react').EmbedHTMLAttributes<HTMLEmbedElement>
            ) => ReactNode)
        fieldset:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLFieldSetElement> &
                import('react').FieldsetHTMLAttributes<HTMLFieldSetElement>
            ) => ReactNode)
        figcaption:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        figure:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        footer:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        form:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLFormElement> &
                import('react').FormHTMLAttributes<HTMLFormElement>
            ) => ReactNode)
        h1:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        h2:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        h3:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        h4:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        h5:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        h6:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadingElement> &
                import('react').HTMLAttributes<HTMLHeadingElement>
            ) => ReactNode)
        head:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHeadElement> &
                import('react').HTMLAttributes<HTMLHeadElement>
            ) => ReactNode)
        header:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        hgroup:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        hr:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHRElement> &
                import('react').HTMLAttributes<HTMLHRElement>
            ) => ReactNode)
        html:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLHtmlElement> &
                import('react').HtmlHTMLAttributes<HTMLHtmlElement>
            ) => ReactNode)
        i:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        iframe:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLIFrameElement> &
                import('react').IframeHTMLAttributes<HTMLIFrameElement>
            ) => ReactNode)
        img:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLImageElement> &
                import('react').ImgHTMLAttributes<HTMLImageElement>
            ) => ReactNode)
        input:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLInputElement> &
                import('react').InputHTMLAttributes<HTMLInputElement>
            ) => ReactNode)
        ins:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLModElement> &
                import('react').InsHTMLAttributes<HTMLModElement>
            ) => ReactNode)
        kbd:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        keygen:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').KeygenHTMLAttributes<HTMLElement>
            ) => ReactNode)
        label:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLLabelElement> &
                import('react').LabelHTMLAttributes<HTMLLabelElement>
            ) => ReactNode)
        legend:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLLegendElement> &
                import('react').HTMLAttributes<HTMLLegendElement>
            ) => ReactNode)
        li:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLLIElement> &
                import('react').LiHTMLAttributes<HTMLLIElement>
            ) => ReactNode)
        link:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLLinkElement> &
                import('react').LinkHTMLAttributes<HTMLLinkElement>
            ) => ReactNode)
        main:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        map:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLMapElement> &
                import('react').MapHTMLAttributes<HTMLMapElement>
            ) => ReactNode)
        mark:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        menu:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').MenuHTMLAttributes<HTMLElement>
            ) => ReactNode)
        menuitem:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        meta:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLMetaElement> &
                import('react').MetaHTMLAttributes<HTMLMetaElement>
            ) => ReactNode)
        meter:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').MeterHTMLAttributes<HTMLElement>
            ) => ReactNode)
        nav:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        noindex:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        noscript:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        object:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLObjectElement> &
                import('react').ObjectHTMLAttributes<HTMLObjectElement>
            ) => ReactNode)
        ol:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLOListElement> &
                import('react').OlHTMLAttributes<HTMLOListElement>
            ) => ReactNode)
        optgroup:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLOptGroupElement> &
                import('react').OptgroupHTMLAttributes<HTMLOptGroupElement>
            ) => ReactNode)
        option:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLOptionElement> &
                import('react').OptionHTMLAttributes<HTMLOptionElement>
            ) => ReactNode)
        output:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').OutputHTMLAttributes<HTMLElement>
            ) => ReactNode)
        p:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLParagraphElement> &
                import('react').HTMLAttributes<HTMLParagraphElement>
            ) => ReactNode)
        param:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLParamElement> &
                import('react').ParamHTMLAttributes<HTMLParamElement>
            ) => ReactNode)
        picture:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        pre:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLPreElement> &
                import('react').HTMLAttributes<HTMLPreElement>
            ) => ReactNode)
        progress:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLProgressElement> &
                import('react').ProgressHTMLAttributes<HTMLProgressElement>
            ) => ReactNode)
        q:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLQuoteElement> &
                import('react').QuoteHTMLAttributes<HTMLQuoteElement>
            ) => ReactNode)
        rp:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        rt:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        ruby:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        s:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        samp:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        slot:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLSlotElement> &
                import('react').SlotHTMLAttributes<HTMLSlotElement>
            ) => ReactNode)
        script:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLScriptElement> &
                import('react').ScriptHTMLAttributes<HTMLScriptElement>
            ) => ReactNode)
        section:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        select:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLSelectElement> &
                import('react').SelectHTMLAttributes<HTMLSelectElement>
            ) => ReactNode)
        small:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        source:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLSourceElement> &
                import('react').SourceHTMLAttributes<HTMLSourceElement>
            ) => ReactNode)
        span:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLSpanElement> &
                import('react').HTMLAttributes<HTMLSpanElement>
            ) => ReactNode)
        strong:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        style:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLStyleElement> &
                import('react').StyleHTMLAttributes<HTMLStyleElement>
            ) => ReactNode)
        sub:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        summary:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        sup:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        table:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableElement> &
                import('react').TableHTMLAttributes<HTMLTableElement>
            ) => ReactNode)
        template:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTemplateElement> &
                import('react').HTMLAttributes<HTMLTemplateElement>
            ) => ReactNode)
        tbody:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableSectionElement> &
                import('react').HTMLAttributes<HTMLTableSectionElement>
            ) => ReactNode)
        td:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableDataCellElement> &
                import('react').TdHTMLAttributes<HTMLTableDataCellElement>
            ) => ReactNode)
        textarea:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTextAreaElement> &
                import('react').TextareaHTMLAttributes<HTMLTextAreaElement>
            ) => ReactNode)
        tfoot:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableSectionElement> &
                import('react').HTMLAttributes<HTMLTableSectionElement>
            ) => ReactNode)
        th:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableHeaderCellElement> &
                import('react').ThHTMLAttributes<HTMLTableHeaderCellElement>
            ) => ReactNode)
        thead:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableSectionElement> &
                import('react').HTMLAttributes<HTMLTableSectionElement>
            ) => ReactNode)
        time:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').TimeHTMLAttributes<HTMLElement>
            ) => ReactNode)
        title:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTitleElement> &
                import('react').HTMLAttributes<HTMLTitleElement>
            ) => ReactNode)
        tr:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTableRowElement> &
                import('react').HTMLAttributes<HTMLTableRowElement>
            ) => ReactNode)
        track:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLTrackElement> &
                import('react').TrackHTMLAttributes<HTMLTrackElement>
            ) => ReactNode)
        u:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        ul:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLUListElement> &
                import('react').HTMLAttributes<HTMLUListElement>
            ) => ReactNode)
        var:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        video:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLVideoElement> &
                import('react').VideoHTMLAttributes<HTMLVideoElement>
            ) => ReactNode)
        wbr:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLElement> &
                import('react').HTMLAttributes<HTMLElement>
            ) => ReactNode)
        webview:
          | string
          | ((
              props: WithNode &
                import('react').ClassAttributes<HTMLWebViewElement> &
                import('react').WebViewHTMLAttributes<HTMLWebViewElement>
            ) => ReactNode)
        svg:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGSVGElement>
            ) => ReactNode)
        animate:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGElement>
            ) => ReactNode)
        animateMotion:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGElement>
            ) => ReactNode)
        animateTransform:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGElement>
            ) => ReactNode)
        circle:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGCircleElement>
            ) => ReactNode)
        clipPath:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGClipPathElement>
            ) => ReactNode)
        defs:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGDefsElement>
            ) => ReactNode)
        desc:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGDescElement>
            ) => ReactNode)
        ellipse:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGEllipseElement>
            ) => ReactNode)
        feBlend:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEBlendElement>
            ) => ReactNode)
        feColorMatrix:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEColorMatrixElement>
            ) => ReactNode)
        feComponentTransfer:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEComponentTransferElement>
            ) => ReactNode)
        feComposite:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFECompositeElement>
            ) => ReactNode)
        feConvolveMatrix:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEConvolveMatrixElement>
            ) => ReactNode)
        feDiffuseLighting:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEDiffuseLightingElement>
            ) => ReactNode)
        feDisplacementMap:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEDisplacementMapElement>
            ) => ReactNode)
        feDistantLight:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEDistantLightElement>
            ) => ReactNode)
        feDropShadow:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEDropShadowElement>
            ) => ReactNode)
        feFlood:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEFloodElement>
            ) => ReactNode)
        feFuncA:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEFuncAElement>
            ) => ReactNode)
        feFuncB:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEFuncBElement>
            ) => ReactNode)
        feFuncG:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEFuncGElement>
            ) => ReactNode)
        feFuncR:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEFuncRElement>
            ) => ReactNode)
        feGaussianBlur:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFEGaussianBlurElement>
            ) => ReactNode)
        feImage:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEImageElement>
            ) => ReactNode)
        feMerge:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEMergeElement>
            ) => ReactNode)
        feMergeNode:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEMergeNodeElement>
            ) => ReactNode)
        feMorphology:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEMorphologyElement>
            ) => ReactNode)
        feOffset:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEOffsetElement>
            ) => ReactNode)
        fePointLight:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFEPointLightElement>
            ) => ReactNode)
        feSpecularLighting:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGFESpecularLightingElement>
            ) => ReactNode)
        feSpotLight:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFESpotLightElement>
            ) => ReactNode)
        feTile:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFETileElement>
            ) => ReactNode)
        feTurbulence:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFETurbulenceElement>
            ) => ReactNode)
        filter:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGFilterElement>
            ) => ReactNode)
        foreignObject:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGForeignObjectElement>
            ) => ReactNode)
        g:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGGElement>
            ) => ReactNode)
        image:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGImageElement>
            ) => ReactNode)
        line:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGLineElement>
            ) => ReactNode)
        linearGradient:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGLinearGradientElement>
            ) => ReactNode)
        marker:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGMarkerElement>
            ) => ReactNode)
        mask:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGMaskElement>
            ) => ReactNode)
        metadata:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGMetadataElement>
            ) => ReactNode)
        mpath:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGElement>
            ) => ReactNode)
        path:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGPathElement>
            ) => ReactNode)
        pattern:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGPatternElement>
            ) => ReactNode)
        polygon:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGPolygonElement>
            ) => ReactNode)
        polyline:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGPolylineElement>
            ) => ReactNode)
        radialGradient:
          | string
          | ((
              props: WithNode &
                import('react').SVGProps<SVGRadialGradientElement>
            ) => ReactNode)
        rect:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGRectElement>
            ) => ReactNode)
        stop:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGStopElement>
            ) => ReactNode)
        switch:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGSwitchElement>
            ) => ReactNode)
        symbol:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGSymbolElement>
            ) => ReactNode)
        text:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGTextElement>
            ) => ReactNode)
        textPath:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGTextPathElement>
            ) => ReactNode)
        tspan:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGTSpanElement>
            ) => ReactNode)
        use:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGUseElement>
            ) => ReactNode)
        view:
          | string
          | ((
              props: WithNode & import('react').SVGProps<SVGViewElement>
            ) => ReactNode)
      }>
    | undefined
}
export type ComponentsWithoutNodeOptions = {
  /**
   * Expose hast elements as a `node` field in components.
   */
  passNode?: false | undefined
  /**
   * Override default elements (such as `<a>`, `<p>`, etcetera) by passing an
   * object mapping tag names to components.
   */
  components?:
    | Partial<{
        a:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AnchorHTMLAttributes<HTMLAnchorElement>,
                HTMLAnchorElement
              >
            ) => ReactNode)
        abbr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        address:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        area:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AreaHTMLAttributes<HTMLAreaElement>,
                HTMLAreaElement
              >
            ) => ReactNode)
        article:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        aside:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        audio:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AudioHTMLAttributes<HTMLAudioElement>,
                HTMLAudioElement
              >
            ) => ReactNode)
        b:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        base:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').BaseHTMLAttributes<HTMLBaseElement>,
                HTMLBaseElement
              >
            ) => ReactNode)
        bdi:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        bdo:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        big:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        blockquote:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').BlockquoteHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        body:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLBodyElement>,
                HTMLBodyElement
              >
            ) => ReactNode)
        br:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLBRElement>,
                HTMLBRElement
              >
            ) => ReactNode)
        button:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ButtonHTMLAttributes<HTMLButtonElement>,
                HTMLButtonElement
              >
            ) => ReactNode)
        canvas:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').CanvasHTMLAttributes<HTMLCanvasElement>,
                HTMLCanvasElement
              >
            ) => ReactNode)
        caption:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        cite:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        code:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        col:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ColHTMLAttributes<HTMLTableColElement>,
                HTMLTableColElement
              >
            ) => ReactNode)
        colgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ColgroupHTMLAttributes<HTMLTableColElement>,
                HTMLTableColElement
              >
            ) => ReactNode)
        data:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DataHTMLAttributes<HTMLDataElement>,
                HTMLDataElement
              >
            ) => ReactNode)
        datalist:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDataListElement>,
                HTMLDataListElement
              >
            ) => ReactNode)
        dd:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        del:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DelHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        details:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DetailsHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        dfn:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        dialog:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DialogHTMLAttributes<HTMLDialogElement>,
                HTMLDialogElement
              >
            ) => ReactNode)
        div:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDivElement>,
                HTMLDivElement
              >
            ) => ReactNode)
        dl:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDListElement>,
                HTMLDListElement
              >
            ) => ReactNode)
        dt:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        em:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        embed:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').EmbedHTMLAttributes<HTMLEmbedElement>,
                HTMLEmbedElement
              >
            ) => ReactNode)
        fieldset:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').FieldsetHTMLAttributes<HTMLFieldSetElement>,
                HTMLFieldSetElement
              >
            ) => ReactNode)
        figcaption:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        figure:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        footer:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        form:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').FormHTMLAttributes<HTMLFormElement>,
                HTMLFormElement
              >
            ) => ReactNode)
        h1:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h2:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h3:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h4:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h5:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h6:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        head:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadElement>,
                HTMLHeadElement
              >
            ) => ReactNode)
        header:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        hgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        hr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHRElement>,
                HTMLHRElement
              >
            ) => ReactNode)
        html:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HtmlHTMLAttributes<HTMLHtmlElement>,
                HTMLHtmlElement
              >
            ) => ReactNode)
        i:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        iframe:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').IframeHTMLAttributes<HTMLIFrameElement>,
                HTMLIFrameElement
              >
            ) => ReactNode)
        img:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ImgHTMLAttributes<HTMLImageElement>,
                HTMLImageElement
              >
            ) => ReactNode)
        input:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').InputHTMLAttributes<HTMLInputElement>,
                HTMLInputElement
              >
            ) => ReactNode)
        ins:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').InsHTMLAttributes<HTMLModElement>,
                HTMLModElement
              >
            ) => ReactNode)
        kbd:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        keygen:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').KeygenHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        label:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LabelHTMLAttributes<HTMLLabelElement>,
                HTMLLabelElement
              >
            ) => ReactNode)
        legend:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLLegendElement>,
                HTMLLegendElement
              >
            ) => ReactNode)
        li:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LiHTMLAttributes<HTMLLIElement>,
                HTMLLIElement
              >
            ) => ReactNode)
        link:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LinkHTMLAttributes<HTMLLinkElement>,
                HTMLLinkElement
              >
            ) => ReactNode)
        main:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        map:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MapHTMLAttributes<HTMLMapElement>,
                HTMLMapElement
              >
            ) => ReactNode)
        mark:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        menu:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MenuHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        menuitem:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        meta:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MetaHTMLAttributes<HTMLMetaElement>,
                HTMLMetaElement
              >
            ) => ReactNode)
        meter:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MeterHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        nav:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        noindex:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        noscript:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        object:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ObjectHTMLAttributes<HTMLObjectElement>,
                HTMLObjectElement
              >
            ) => ReactNode)
        ol:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OlHTMLAttributes<HTMLOListElement>,
                HTMLOListElement
              >
            ) => ReactNode)
        optgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OptgroupHTMLAttributes<HTMLOptGroupElement>,
                HTMLOptGroupElement
              >
            ) => ReactNode)
        option:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OptionHTMLAttributes<HTMLOptionElement>,
                HTMLOptionElement
              >
            ) => ReactNode)
        output:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OutputHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        p:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLParagraphElement>,
                HTMLParagraphElement
              >
            ) => ReactNode)
        param:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ParamHTMLAttributes<HTMLParamElement>,
                HTMLParamElement
              >
            ) => ReactNode)
        picture:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        pre:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLPreElement>,
                HTMLPreElement
              >
            ) => ReactNode)
        progress:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ProgressHTMLAttributes<HTMLProgressElement>,
                HTMLProgressElement
              >
            ) => ReactNode)
        q:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').QuoteHTMLAttributes<HTMLQuoteElement>,
                HTMLQuoteElement
              >
            ) => ReactNode)
        rp:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        rt:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        ruby:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        s:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        samp:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        slot:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SlotHTMLAttributes<HTMLSlotElement>,
                HTMLSlotElement
              >
            ) => ReactNode)
        script:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ScriptHTMLAttributes<HTMLScriptElement>,
                HTMLScriptElement
              >
            ) => ReactNode)
        section:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        select:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SelectHTMLAttributes<HTMLSelectElement>,
                HTMLSelectElement
              >
            ) => ReactNode)
        small:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        source:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SourceHTMLAttributes<HTMLSourceElement>,
                HTMLSourceElement
              >
            ) => ReactNode)
        span:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLSpanElement>,
                HTMLSpanElement
              >
            ) => ReactNode)
        strong:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        style:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').StyleHTMLAttributes<HTMLStyleElement>,
                HTMLStyleElement
              >
            ) => ReactNode)
        sub:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        summary:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        sup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        table:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TableHTMLAttributes<HTMLTableElement>,
                HTMLTableElement
              >
            ) => ReactNode)
        template:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTemplateElement>,
                HTMLTemplateElement
              >
            ) => ReactNode)
        tbody:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        td:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TdHTMLAttributes<HTMLTableDataCellElement>,
                HTMLTableDataCellElement
              >
            ) => ReactNode)
        textarea:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TextareaHTMLAttributes<HTMLTextAreaElement>,
                HTMLTextAreaElement
              >
            ) => ReactNode)
        tfoot:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        th:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ThHTMLAttributes<HTMLTableHeaderCellElement>,
                HTMLTableHeaderCellElement
              >
            ) => ReactNode)
        thead:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        time:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TimeHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        title:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTitleElement>,
                HTMLTitleElement
              >
            ) => ReactNode)
        tr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableRowElement>,
                HTMLTableRowElement
              >
            ) => ReactNode)
        track:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TrackHTMLAttributes<HTMLTrackElement>,
                HTMLTrackElement
              >
            ) => ReactNode)
        u:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        ul:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLUListElement>,
                HTMLUListElement
              >
            ) => ReactNode)
        var:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        video:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').VideoHTMLAttributes<HTMLVideoElement>,
                HTMLVideoElement
              >
            ) => ReactNode)
        wbr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        webview:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').WebViewHTMLAttributes<HTMLWebViewElement>,
                HTMLWebViewElement
              >
            ) => ReactNode)
        svg:
          | string
          | ((props: import('react').SVGProps<SVGSVGElement>) => ReactNode)
        animate:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        animateMotion:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        animateTransform:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        circle:
          | string
          | ((props: import('react').SVGProps<SVGCircleElement>) => ReactNode)
        clipPath:
          | string
          | ((props: import('react').SVGProps<SVGClipPathElement>) => ReactNode)
        defs:
          | string
          | ((props: import('react').SVGProps<SVGDefsElement>) => ReactNode)
        desc:
          | string
          | ((props: import('react').SVGProps<SVGDescElement>) => ReactNode)
        ellipse:
          | string
          | ((props: import('react').SVGProps<SVGEllipseElement>) => ReactNode)
        feBlend:
          | string
          | ((props: import('react').SVGProps<SVGFEBlendElement>) => ReactNode)
        feColorMatrix:
          | string
          | ((
              props: import('react').SVGProps<SVGFEColorMatrixElement>
            ) => ReactNode)
        feComponentTransfer:
          | string
          | ((
              props: import('react').SVGProps<SVGFEComponentTransferElement>
            ) => ReactNode)
        feComposite:
          | string
          | ((
              props: import('react').SVGProps<SVGFECompositeElement>
            ) => ReactNode)
        feConvolveMatrix:
          | string
          | ((
              props: import('react').SVGProps<SVGFEConvolveMatrixElement>
            ) => ReactNode)
        feDiffuseLighting:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDiffuseLightingElement>
            ) => ReactNode)
        feDisplacementMap:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDisplacementMapElement>
            ) => ReactNode)
        feDistantLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDistantLightElement>
            ) => ReactNode)
        feDropShadow:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDropShadowElement>
            ) => ReactNode)
        feFlood:
          | string
          | ((props: import('react').SVGProps<SVGFEFloodElement>) => ReactNode)
        feFuncA:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncAElement>) => ReactNode)
        feFuncB:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncBElement>) => ReactNode)
        feFuncG:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncGElement>) => ReactNode)
        feFuncR:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncRElement>) => ReactNode)
        feGaussianBlur:
          | string
          | ((
              props: import('react').SVGProps<SVGFEGaussianBlurElement>
            ) => ReactNode)
        feImage:
          | string
          | ((props: import('react').SVGProps<SVGFEImageElement>) => ReactNode)
        feMerge:
          | string
          | ((props: import('react').SVGProps<SVGFEMergeElement>) => ReactNode)
        feMergeNode:
          | string
          | ((
              props: import('react').SVGProps<SVGFEMergeNodeElement>
            ) => ReactNode)
        feMorphology:
          | string
          | ((
              props: import('react').SVGProps<SVGFEMorphologyElement>
            ) => ReactNode)
        feOffset:
          | string
          | ((props: import('react').SVGProps<SVGFEOffsetElement>) => ReactNode)
        fePointLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFEPointLightElement>
            ) => ReactNode)
        feSpecularLighting:
          | string
          | ((
              props: import('react').SVGProps<SVGFESpecularLightingElement>
            ) => ReactNode)
        feSpotLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFESpotLightElement>
            ) => ReactNode)
        feTile:
          | string
          | ((props: import('react').SVGProps<SVGFETileElement>) => ReactNode)
        feTurbulence:
          | string
          | ((
              props: import('react').SVGProps<SVGFETurbulenceElement>
            ) => ReactNode)
        filter:
          | string
          | ((props: import('react').SVGProps<SVGFilterElement>) => ReactNode)
        foreignObject:
          | string
          | ((
              props: import('react').SVGProps<SVGForeignObjectElement>
            ) => ReactNode)
        g:
          | string
          | ((props: import('react').SVGProps<SVGGElement>) => ReactNode)
        image:
          | string
          | ((props: import('react').SVGProps<SVGImageElement>) => ReactNode)
        line:
          | string
          | ((props: import('react').SVGProps<SVGLineElement>) => ReactNode)
        linearGradient:
          | string
          | ((
              props: import('react').SVGProps<SVGLinearGradientElement>
            ) => ReactNode)
        marker:
          | string
          | ((props: import('react').SVGProps<SVGMarkerElement>) => ReactNode)
        mask:
          | string
          | ((props: import('react').SVGProps<SVGMaskElement>) => ReactNode)
        metadata:
          | string
          | ((props: import('react').SVGProps<SVGMetadataElement>) => ReactNode)
        mpath:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        path:
          | string
          | ((props: import('react').SVGProps<SVGPathElement>) => ReactNode)
        pattern:
          | string
          | ((props: import('react').SVGProps<SVGPatternElement>) => ReactNode)
        polygon:
          | string
          | ((props: import('react').SVGProps<SVGPolygonElement>) => ReactNode)
        polyline:
          | string
          | ((props: import('react').SVGProps<SVGPolylineElement>) => ReactNode)
        radialGradient:
          | string
          | ((
              props: import('react').SVGProps<SVGRadialGradientElement>
            ) => ReactNode)
        rect:
          | string
          | ((props: import('react').SVGProps<SVGRectElement>) => ReactNode)
        stop:
          | string
          | ((props: import('react').SVGProps<SVGStopElement>) => ReactNode)
        switch:
          | string
          | ((props: import('react').SVGProps<SVGSwitchElement>) => ReactNode)
        symbol:
          | string
          | ((props: import('react').SVGProps<SVGSymbolElement>) => ReactNode)
        text:
          | string
          | ((props: import('react').SVGProps<SVGTextElement>) => ReactNode)
        textPath:
          | string
          | ((props: import('react').SVGProps<SVGTextPathElement>) => ReactNode)
        tspan:
          | string
          | ((props: import('react').SVGProps<SVGTSpanElement>) => ReactNode)
        use:
          | string
          | ((props: import('react').SVGProps<SVGUseElement>) => ReactNode)
        view:
          | string
          | ((props: import('react').SVGProps<SVGViewElement>) => ReactNode)
      }>
    | undefined
}
export type Options = SharedOptions &
  (ComponentsWithNodeOptions | ComponentsWithoutNodeOptions)
